==> anticheat-center-api-xj-0403.0.2-sources.jar: cn/com/duiba/anticheat/center/api/dto/ActivityBlackListDto.java <==
package cn.com.duiba.anticheat.center.api.dto;

import java.io.Serializable;
import java.util.Date;

public class ActivityBlackListDto implements Serializable {
    /**
    * 主键
    */
    private Long id;

    /**
    * 兑吧用户id
    */
    private Integer customerId;

    /**
    * 应用id
    */
    private Long appId;

    /**
    * 活动id
    */
    private Long projectId;

    /**
    * ip地址
    */
    private String ip;

    /**
    * UA
    */
    private String ua;

    /**
    * 设备id
    */
    private String devicedId;

    /**
    * 封禁原因标识
    */
    private Integer bannedSign;

    /**
    * 封禁原因描述
    */
    private String bannedDescription;

    /**
    * 封禁时间
    */
    private Date gmtCreate;

    /**
    * 更新时间
    */
    private Date gmtModified;

    /**
    * 删除标识  未删除0 已删除1
    */
    private Boolean isDel;

    private static final long serialVersionUID = 1L;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Integer customerId) {
        this.customerId = customerId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getUa() {
        return ua;
    }

    public void setUa(String ua) {
        this.ua = ua;
    }

    public String getDevicedId() {
        return devicedId;
    }

    public void setDevicedId(String devicedId) {
        this.devicedId = devicedId;
    }

    public Integer getBannedSign() {
        return bannedSign;
    }

    public void setBannedSign(Integer bannedSign) {
        this.bannedSign = bannedSign;
    }

    public String getBannedDescription() {
        return bannedDescription;
    }

    public void setBannedDescription(String bannedDescription) {
        this.bannedDescription = bannedDescription;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Boolean getIsDel() {
        return isDel;
    }

    public void setIsDel(Boolean isDel) {
        this.isDel = isDel;
    }
}

==> anticheat-center-api-xj-0403.0.4-sources.jar: cn/com/duiba/anticheat/center/api/dto/ActivityBlackListDto.java <==
package cn.com.duiba.anticheat.center.api.dto;

import java.io.Serializable;
import java.util.Date;

public class ActivityBlackListDto implements Serializable {
    /**
    * 主键
    */
    private Long id;

    /**
    * 兑吧用户id
    */
    private Long customerId;

    /**
    * 应用id
    */
    private Long appId;

    /**
    * 活动id
    */
    private Long projectId;

    /**
    * ip地址
    */
    private String ip;

    /**
    * UA
    */
    private String ua;

    /**
    * 设备id
    */
    private String devicedId;

    /**
    * 封禁原因标识
    */
    private Integer bannedSign;

    /**
    * 封禁原因描述
    */
    private String bannedDescription;

    /**
    * 封禁时间
    */
    private Date gmtCreate;

    /**
    * 更新时间
    */
    private Date gmtModified;

    /**
    * 删除标识  未删除0 已删除1
    */
    private Boolean isDel;

    private static final long serialVersionUID = 1L;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getUa() {
        return ua;
    }

    public void setUa(String ua) {
        this.ua = ua;
    }

    public String getDevicedId() {
        return devicedId;
    }

    public void setDevicedId(String devicedId) {
        this.devicedId = devicedId;
    }

    public Integer getBannedSign() {
        return bannedSign;
    }

    public void setBannedSign(Integer bannedSign) {
        this.bannedSign = bannedSign;
    }

    public String getBannedDescription() {
        return bannedDescription;
    }

    public void setBannedDescription(String bannedDescription) {
        this.bannedDescription = bannedDescription;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Boolean getIsDel() {
        return isDel;
    }

    public void setIsDel(Boolean isDel) {
        this.isDel = isDel;
    }
}
